@@ -4,26 +4,47 @@ use 5.009;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 use Carp;
 use autodie;
 
+sub CFGFILE () {'.perlminlint.yml'}
+
 use App::perlminlint::Object -as_base,
-  [fields => qw/libs
-		no_stderr
+  [fields => qw/no_stderr
 		help
-		_plugins/];
+		verbose
+		dryrun
+
+		no_auto_libdir
+
+		_plugins
+		_lib_list _lib_dict
+		_perl_opts
+	       /];
 
 require lib;
 require File::Basename;
 
 use Module::Pluggable require => 1, sub_name => '_plugins';
 
+
 sub usage {
   (my MY $app) = @_;
   die <<END;
-Usage: @{[$app->basename($0)]} FILES...
+Usage: @{[$app->basename($0)]} [opts..] YOUR_SCRIPT
+
+Options:
+-v --verbose
+-n --dryrun
+-w -c -wc    (just ignored)
+
+Pass-through Options:
+-IDIR
+-Mmodule
+-mmodule
+-dDEBUG
 END
 }
 
@@ -34,18 +55,27 @@ sub run {
 			  ($argv, {h => 'help'
 				   # Just to ignore -w -c -wc
 				   , w => '', c => '', wc => ''
-				 }));
+				   , v => 'verbose'
+				   , n => 'dryrun'
+				 }
+			   , qr{^-[ImMd]}, my $perl_opts = []
+			 ));
+
+  # -IDIR, -mmod, -MMod
+  push @{$app->{_perl_opts}}, @$perl_opts;
+
+  if ($app->{help} or not @$argv) {
+    $app->usage;
+  }
+
+  $app->find_and_load_config_from(@$argv);
 
   if ($app->{no_stderr}) {
     close STDERR;
     open STDERR, '>&STDOUT';
   }
 
-  if ($app->{help} or not @$argv) {
-    $app->usage;
-  }
-
-  $app->add_lib_to_inc_for(@$argv);
+  $app->add_lib_to_inc_for(@$argv) if not $app->{no_auto_libdir};
 
   my @res = $app->lint(@$argv);
   if (@res) {
@@ -55,20 +85,69 @@ sub run {
   }
 }
 
-sub add_lib_to_inc_for {
-  (my MY $self, my $fn) = @_;
-  my @dirs = $self->splitdir($self->rel2abs($fn));
+sub after_new {
+  (my MY $self) = @_;
+  foreach my $lib (@INC) {
+    $self->{_lib_dict}{$lib}++;
+  }
+}
+
+sub upward_first_file_from (&@) {
+  my ($code, $lookfor, $startFn) = @_;
+  my @dirs = MY->splitdir(MY->rel2abs($startFn));
   pop @dirs;
+  local $_;
   while (@dirs) {
-    -d (my $libdir = $self->catdir(@dirs, "lib"))
+    -e (my $fn = MY->catdir(@dirs, $lookfor))
       or next;
-    import lib $libdir;
-    last;
+    $code->($_ = $fn)
+      and last;
   } continue {
     pop @dirs;
   }
 }
 
+sub add_lib_to_inc_for {
+  (my MY $self, my $fn) = @_;
+
+  upward_first_file_from {
+    my ($libdir) = @_;
+    if (-d $libdir) {
+      if (not $self->{_lib_dict}{$libdir}) {
+	import lib $libdir;
+	push @{$self->{_lib_list}}, $libdir;
+      }
+      1;
+    }
+  } lib => $fn;
+}
+
+sub find_and_load_config_from {
+  (my MY $self, my $fn) = @_;
+  upward_first_file_from {
+    $self->load_config($_);
+  } CFGFILE, $fn;
+}
+
+sub load_config {
+  (my MY $self, my $fn) = @_;
+  if ($self->{verbose}) {
+    print STDERR "# loading config: $fn\n";
+  }
+
+  eval {require YAML::Tiny};
+  if ($@) {
+    die "Can't load '$fn'. Please install YAML::Tiny\n";
+  }
+
+  my $yaml = YAML::Tiny->read($fn);
+  if (not $yaml->[0] and ref $yaml->[0] eq 'HASH') {
+    die "Invalid data in $fn. Only HASH is allowed\n";
+  }
+
+  $self->configure($yaml->[0]);
+}
+
 sub lint {
   (my MY $self, my $fn) = @_;
 
@@ -118,7 +197,16 @@ sub plugins {
 
 sub run_perl {
   my MY $self = shift;
-  system($^X, @_) == 0
+  my @opts;
+  push @opts, lexpand($self->{_perl_opts});
+  push @opts, map {"-I$_"} lexpand($self->{_lib_list});
+  if ($self->{verbose} || $self->{dryrun}) {
+    print STDERR join(" ", "#", $^X, @opts, @_), "\n";
+  }
+  if ($self->{dryrun}) {
+    return;
+  }
+  system($^X, @opts, @_) == 0
     or exit $? >> 8;
 }
 
@@ -144,6 +232,16 @@ sub rootname {
   join "", $fn, @_;
 }
 
+sub lexpand {
+  if (not defined $_[0]) {
+    wantarray ? () : 0;
+  } elsif (not ref $_[0]) {
+    $_[0]
+  } else {
+    @{$_[0]};
+  }
+}
+
 sub inc_opt {
   my ($app, $file, $modname) = @_;
   (my $no_pm = $file) =~ s/\.\w+$//;
@@ -186,20 +284,37 @@ sub parse_shbang {
 # XXX: Real new and options...
 
 sub parse_argv {
-  my ($pack, $list, $alias) = @_;
+  my ($pack, $list, $alias, $special_re, $special_list) = @_;
   my @opts;
-  while (@$list
-	 and my ($k, $v) = $list->[0] =~ /^--?([-\w]+)(?:=(.*))?/) {
-    $k =~ s/-/_/g;
-    my $opt = $alias->{$k} // $k;
-    next if $opt eq ''; # To drop compat-only option.
-    push @opts, $opt => ($v // 1);
+  while (@$list) {
+    if ($special_re and $list->[0] =~ $special_re) {
+      push @$special_list, $list->[0]
+    } elsif (my ($k, $v) = $list->[0] =~ /^--?(\w[-\w]*)(?:=(.*))?/) {
+      $k =~ s/-/_/g;
+      my $opt = $alias->{$k} // $k;
+      next if $opt eq ''; # To drop compat-only option.
+      push @opts, $opt => ($v // 1);
+    } else {
+      last;
+    }
   } continue {
     shift @$list;
   }
   @opts;
 }
 
+sub parse_perl_opts {
+  (my MY $self, my $list) = @_;
+
+  my @opts;
+  while (@$list and defined $list->[0]
+	 and $list->[0] =~ m{^-[ImMd]}) {
+    push @opts, shift @$list;
+  }
+
+  @opts;
+}
+
 1; # End of App::perlminlint
 
 __END__
